DMTI Python Library is a library to optimize and make your data processing easier, in this library we handling much basic tasks and make it simpler by using one line of code
Install
pip install dmtipy
Usage
from .create_table_from_csv import create_sql_table_from_csv